/****************************************************************************
**
** Copyright (C) 2010-2011 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (ivan.frade@nokia.com)
**
** This file is part of QtSparqlTracker library.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial Usage
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
** If you have questions regarding the use of this file, please contact
** Nokia at ivan.frade@nokia.com.
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef TRACKERCHANGENOTIFIER_H
#define TRACKERCHANGENOTIFIER_H

#include <QObject>

#ifndef Q_EXPORT_QTSPARQLTRACKER
# if defined(QTSPARQLTRACKER_BUILD)
#  define Q_EXPORT_QTSPARQLTRACKER Q_DECL_EXPORT
# else
#  define Q_EXPORT_QTSPARQLTRACKER Q_DECL_IMPORT
# endif
#endif

class TrackerChangeNotifierPrivate;

/// A class that wraps around the GraphUpdate D-Bus signal emitted by Tracker.
class Q_EXPORT_QTSPARQLTRACKER TrackerChangeNotifier : public QObject
{
    Q_OBJECT
public:
    struct Quad
    {
        int graph, subject, predicate, object;
    };
    TrackerChangeNotifier(const QString& className,
                           QObject* parent = 0);
    ~TrackerChangeNotifier();
    QString watchedClass() const;
    void setSignalsEnabled(bool enable=true);
    void setBufferSize(int newSize);
Q_SIGNALS:
    /// Emitted when tracker signals that triples have been deleted or inserted.
    /// \a deletes is the list of deleted triples, \a inserts is the list of
    /// inserted triples. The lists contain \a Quad objects, and each Quad
    /// object contains the tracker id's of a triple. If the object of the
    /// triple is a literal, the corresponding Quad will contain 0 as its
    /// object.
    void changed(QList<TrackerChangeNotifier::Quad> deletes,
                 QList<TrackerChangeNotifier::Quad> inserts);
private:
    TrackerChangeNotifierPrivate* d;
    friend class TrackerChangeNotifierPrivate;
};

#ifndef QT_NO_DEBUG_STREAM
Q_EXPORT_QTSPARQLTRACKER QDebug operator<<(QDebug, const TrackerChangeNotifier::Quad &);
#endif

#endif // TRACKERCHANGENOTIFIER_H
